<?php

/**
 * vpanel-stack
 * https://git.stack-source.com/msb/vpanel-stack
 * Copyright (c) 2022 Matthew Saunders Brown <matthewsaundersbrown@gmail.com>
 * GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 */

namespace Panel;

class Login extends \Panel {

  function beforeRoute($f3) {

    parent::beforeRoute($f3);

  }

  static function get($f3) {

    /* requests from ADMINIP are automatically authenticated */
    if ($f3->get('ADMINIP') != '' && $f3->get('ADMINIP') == $f3->get('IP')) {
      $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
      $f3->set('SESSION.access', 'admin');
      $messages[] = "You have been automatically logged in with connection from Admin IP " . $f3->get('IP');
      $f3->set('SESSION.messages', $messages);
      $f3->reroute('/');
    } else {
      /* all others must log in with valid username */
      echo \Template::instance()->render('login.html');
    }

  }

  function post($f3) {

    /* get vars */
    $username = $_POST['username'];
    $password = $_POST['password'];
    $domain = $f3->get('SESSION.domain');

    /* detect mapping, authenticate */
    if ($f3->get('NAV.mapping') == 'vmail') {
      /* enforce email address format for username */
      if (! strstr($username, '@')) {
        $username = "$username@$domain";
      }
      $emaildomain = $f3->get('HOST');
      $auth = new \Auth('smtp', ['host' => $emaildomain, 'port' => 587, 'scheme' => 'tls']);
      if ($auth->login($username, $password)) {
        /* user passed smtp auth, check for admin access */
        if ($email_array = $f3->call('\Panel::vGet', array("vmail-mboxes-get.sh -e $username -c", FALSE))) {
          if ($email_array[0]['status'] == '1') {
            $messages[] = "Email validated, but does not have admin privileges.";
            $messages[] = "Please log in with an admin account.";
            $f3->set('SESSION.messages', $messages);
            echo \Template::instance()->render('login.html');
//             $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
//             $f3->set('SESSION.access', 'user');
//             $f3->reroute('/');
          } elseif ($email_array[0]['status'] == '2') {
            $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
            $f3->set('SESSION.access', 'admin');
            $f3->reroute('/');
          } else {
            /* invalid email account status, should not happen as user passed smtp auth */
            $messages[] = "System error verifying email account status. Please contact support for further assistance.";
            $f3->set('SESSION.messages', $messages);
            echo \Template::instance()->render('login.html');
          }
        } else {
          /* failed to get email account info, should never happen as user passed smtp auth */
          $messages[] = "System error getting email account status. Please contact support for further assistance.";
          $f3->set('SESSION.messages', $messages);
          echo \Template::instance()->render('login.html');
        }
      } else {
        $messages[] = "Login failed, please try again.";
        $f3->set('SESSION.messages', $messages);
        echo \Template::instance()->render('login.html');
      }
    } else {
      /* not vmail, either vhost or vpanel, both use pwauth */
      unset($output);
      exec("/usr/bin/echo -e '$username\\n$password\\n' | /usr/sbin/pwauth", $output, $result_code);
      if ($result_code == 0) {
        /* user validated, check for vpanel or vhost and futher confirm access */
        if ($f3->get('NAV.mapping') == 'vpanel') {
          /* check for vpanel sudo access */
          unset($output);
          exec("/usr/local/bin/vpanel-verify-access.sh -u $username", $output, $result_code);
          if ($result_code == 0) {
            $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
            $f3->reroute('/');
          } else {
            $messages[] = "User validated, but does not have admin privileges.";
            $messages[] = "Please log in as an admin user.";
            $f3->set('SESSION.messages', $messages);
            echo \Template::instance()->render('login.html');
          }
        } elseif ($f3->get('NAV.mapping') == 'vhost') {
          /* user authenticated, check if they own requested domain */
          if ($domain_array = $f3->call('\Panel::vGet', array("vhost-get.sh -u $username -d $domain -c", FALSE))) {
            $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
            $f3->reroute('/');
          } else {
            /* user does not own domain, check if user is a vpanel admin */
            exec("/usr/local/bin/vpanel-verify-access.sh -u $username", $output, $result_code);
            if ($result_code == 0) {
              $f3->set('SESSION.expiration', time() + $f3->get('TIMEOUT'));
              $f3->reroute('/');
            } else {
              /* user does not own domain, and is not a vpanel admin */
              $messages[] = "User validated, but does not have admin privileges for $domain.";
              $messages[] = "Please try another username.";
              $f3->set('SESSION.messages', $messages);
              echo \Template::instance()->render('login.html');
            }
          }
        } else {
          $messages[] = "System error. Please confirm URL and try again.";
          $f3->set('SESSION.messages', $messages);
          echo \Template::instance()->render('login.html');
        }
      } else {
        $messages[] = "Login failed, please try again.";
        $f3->set('SESSION.messages', $messages);
        echo \Template::instance()->render('login.html');
      }
    }
  }

}
